@@ -292,6 +292,7 @@ pub fn is_syntax_name(s: &str) -> bool {
       | "macroexpand-1"
       | "macroexpand-all"
       | "foldl" // for performance
+      | "foldl-shortcut" // for performance
       | "try"
       | "sort" // TODO need better solution
       | "defatom"
@@ -316,6 +317,7 @@ pub fn handle_syntax(
     "if" => syntax::syntax_if(nodes, scope, file_ns, program),
     "&let" => syntax::syntax_let(nodes, scope, file_ns, program),
     "foldl" => lists::foldl(nodes, scope, file_ns, program),
+    "foldl-shortcut" => lists::foldl_shortcut(nodes, scope, file_ns, program),
     "macroexpand" => syntax::macroexpand(nodes, scope, file_ns, program),
     "macroexpand-1" => syntax::macroexpand_1(nodes, scope, file_ns, program),
     "macroexpand-all" => syntax::macroexpand_all(nodes, scope, file_ns, program),
